# Golang and GORM - User Registration and Email Verification

In this comprehensive guide, you will learn how to secure a Golang RESTful API with JSON Web Tokens and Email verification. We will start by registering the user, verifying the user's email address, logging in the registered user, and logging out the authenticated user.

![Golang and GORM - User Registration and Email Verification](https://codevoweb.com/wp-content/uploads/2022/08/Golang-and-GORM-User-Registration-and-Email-Verification.webp)

## Topics Covered

- Golang and GORM JWT Authentication Overview
- Create the Database Models with GORM
- Database Migration with GORM
- Generate and Verify the Password with Bcrypt
- Sign and Verify the JWT (JSON Web Tokens)
    - Update the Environment Variables File
    - Validate the Variables with Viper
    - Generate the JSON Web Tokens
    - Verify the JSON Web Tokens
- Create the SMTP Credentials
- Setup the HTML Templates
    - Add the HTML Email Base Template
    - Add the HTML Email CSS Styles
    - Add the Email Verification Template
    - Create the Email Utility Function
- Create the Controller Functions
    - Function to Generate the Verification Code
    - User Registration Controller
    - Verify Email Controller
    - Login User Controller
    - Logout User Controller
    - Get User Profile Controller
- Create the Authentication Guard
- Create Routes for the Controllers
    - Auth Routes
    - User Routes
- Register the Routes and Start the Golang Server

Read the entire article here: [https://codevoweb.com/golang-and-gorm-user-registration-email-verification](https://codevoweb.com/golang-and-gorm-user-registration-email-verification)

Articles in this series:

### 1. How to Setup Golang GORM RESTful API Project with Postgres

[How to Setup Golang GORM RESTful API Project with Postgres](https://codevoweb.com/setup-golang-gorm-restful-api-project-with-postgres/)

### 2. API with Golang + GORM + PostgreSQL: Access & Refresh Tokens

[API with Golang + GORM + PostgreSQL: Access & Refresh Tokens](https://codevoweb.com/golang-gorm-postgresql-user-registration-with-refresh-tokens)

### 3. Golang and GORM - User Registration and Email Verification

[Golang and GORM - User Registration and Email Verification](https://codevoweb.com/golang-and-gorm-user-registration-email-verification)

### 4. Forgot/Reset Passwords in Golang with SMTP HTML Email

[Forgot/Reset Passwords in Golang with SMTP HTML Email](https://codevoweb.com/forgot-reset-passwords-in-golang-with-html-email)

### 5. Build a RESTful CRUD API with Golang

[Build a RESTful CRUD API with Golang](https://codevoweb.com/build-restful-crud-api-with-golang)
